#
# spec file for package ghc-hslua-module-system
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name hslua-module-system
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.1.3
Release:        1.1
Summary:        Lua module wrapper around Haskell's System module
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-directory-prof
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-exceptions-prof
BuildRequires:  ghc-hslua-core-devel
BuildRequires:  ghc-hslua-core-prof
BuildRequires:  ghc-hslua-marshalling-devel
BuildRequires:  ghc-hslua-marshalling-prof
BuildRequires:  ghc-hslua-packaging-devel
BuildRequires:  ghc-hslua-packaging-prof
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-process-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-temporary-devel
BuildRequires:  ghc-temporary-prof
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-lua-devel
BuildRequires:  ghc-tasty-lua-prof
BuildRequires:  ghc-tasty-prof
%endif

%description
Provides access to system information and functionality to Lua scripts via
Haskell's `System` module.

This package is part of HsLua, a Haskell framework built around the embeddable
scripting language <https://lua.org Lua>.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Wed May 21 2025 Peter Simons <psimons@suse.com>
- Update hslua-module-system to version 1.1.3.
  [#]# hslua-module-system-1.1.3
  Released 2025-05-21.
  - Improved docs for the `os` field.
  - Added new function `cmd` that runs system commands.
  - Moved `CHANGELOG.md` to the `extra-doc-files` field in the
    cabal file and also added `README.md` to that field.
* Tue May 28 2024 Peter Simons <psimons@suse.com>
- Update hslua-module-system to version 1.1.2.
  [#]# hslua-module-system-1.1.2
  Released 2024-05-28.
  - Fixed error handling in `with_wd`: exceptions when changing
    directories are now properly converted to Lua errors.
* Thu Jan 18 2024 Peter Simons <psimons@suse.com>
- Update hslua-module-system to version 1.1.1.
  [#]# hslua-module-system-1.1.1
  Released 2024-01-18.
  - Relaxed upper bound for text, allowing text-2.1.
* Thu Apr 13 2023 Peter Simons <psimons@suse.com>
- Update hslua-module-system to version 1.1.0.1.
  [#]# hslua-module-system-1.1.0.1
  Released 2023-03-26.
  - Improve doc strings.
  [#]# hslua-module-system-1.1.0
  - Update to hslua-2.3; this includes the addition of type
    initializers to the module and type specifiers to the fields.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Tue Feb 14 2023 Peter Simons <psimons@suse.com>
- Update hslua-module-system to version 1.0.3.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/hslua-module-system-1.0.3/src/CHANGELOG.md
* Sat Feb 19 2022 Peter Simons <psimons@suse.com>
- Update hslua-module-system to version 1.0.2.
  [#]# hslua-module-system-1.0.2
  Released 2022-02-19.
  - Adjusted package bounds, for hslua-core and hslua-packaging.
* Sun Jan 30 2022 Peter Simons <psimons@suse.com>
- Update hslua-module-system to version 1.0.1 revision 1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/hslua-module-system-1.0.1/src/CHANGELOG.md
* Mon Nov  1 2021 psimons@suse.com
- Update hslua-module-system to version 1.0.0.
  [#]# 1.0.0
  Release pending.
  - Use hslua 2.0.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Sat Oct 17 2020 psimons@suse.com
- Update hslua-module-system to version 0.2.2.1.
  [#]# 0.2.2.1 -- 2020-10-16
  - Relaxed upper bound for hslua, allow `hslua-1.3.*`.
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Sun Aug 16 2020 psimons@suse.com
- Update hslua-module-system to version 0.2.2.
  [#]# 0.2.2 -- 2020-08-15
  - Relaxed upper bound for hslua, allow `hslua-1.2.*`.
  - Improved documentation of internal types.
  - Use tasty-lua for unit tests.
  - Update CI to test with all GHC versions.
* Tue Jun 16 2020 Peter Simons <psimons@suse.com>
- Re-generate file with latest version of spec-cleaner.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sat Jun 15 2019 psimons@suse.com
- Add hslua-module-system at version 0.2.1.
